# Auvio

Let your zuvio roll the call automatically, don’t get up for roll call anymore, give yourself a good morning.


![](https://img.shields.io/pypi/v/auvio.svg)

### install
`pip3 install auvio`

### How to use
1. `from auvio import *`
2. `auvio('YOUR_ZUVIO_EMAIL@PUT.HERE', 'YOUR_ZUVIO_PASSWORD', 'CLASS_NUMBER', Latitude, longitude)`


Argument           | Type  
--------------|-------
email    | str 
password    | str
class number  | str
Latitude | float
longitude | float


3. logout will happen when user puts Ctrl + c or other KeyboardInterrupt commands